export declare type HSL = [number, number, number, number];
export declare type HWB = [number, number, number, number];
export declare type LAB = [number, number, number, number];
export declare type LCH = [number, number, number, number];
export declare type LUV = [number, number, number, number];
export declare type LMS = [number, number, number, number];
export declare type LinearRGB = [number, number, number, number];
export declare type Oklab = [number, number, number, number];
export declare type Oklch = [number, number, number, number];
export declare type sRGB = [number, number, number, number];
export declare type XYZ_D65 = [number, number, number, number];
export declare type Color = string | number | sRGB | LinearRGB | LMS | Oklab | Oklch;
declare type MatrixRow = [number, number, number];
export declare type ColorMatrix = [MatrixRow, MatrixRow, MatrixRow];
/** HSL -> sRGB */
export declare function hslTosRGB(hsl: HSL): sRGB;
/** HWB -> sRGB (https://www.w3.org/TR/css-color-4/#hwb-to-rgb) */
export declare function hwbTosRGB(hwb: HWB): sRGB;
/** Lab -> LCh / Oklab -> Oklch) */
export declare function labToLCH(lab: LAB, ε?: number): LCH;
/** LCh -> Lab / Oklch -> Oklab */
export declare function lchToLAB(lch: LCH): LAB;
/** LMS -> Oklab (via LMS) */
export declare function lmsToOklab(lms: LMS): Oklab;
/** LMS -> Linear sRGB */
export declare function lmsToLinearRGB(lms: LMS): LinearRGB;
/** Linear sRGB -> sRGB */
export declare function linearRGBTosRGB(rgb: LinearRGB): sRGB;
/** Linear sRGB -> LMS */
export declare function linearRGBToLMS(lrgb: LinearRGB): LMS;
/** Linear sRGB -> XYZ (D65) */
export declare function linearRGBToXYZ(rgb: LinearRGB): XYZ_D65;
/** LUV -> sRGB */
/** LUV -> XYZ (D65) */
/** Oklab -> LMS */
export declare function oklabToLMS(oklab: Oklab): sRGB;
/** Oklab -> sRGB */
export declare function oklabTosRGB(oklab: Oklab): sRGB;
/** Oklch -> sRGB */
export declare function oklchTosRGB(oklch: Oklch): sRGB;
/** sRGB -> Linear sRGB */
export declare function sRGBToLinearRGB(rgb: sRGB): LinearRGB;
/** Linear sRGB -> Luv */
/** sRGB -> Oklab */
export declare function sRGBToOklab(rgb: sRGB): Oklab;
/** sRGB -> Oklch */
export declare function sRGBToOklch(rgb: sRGB): Oklch;
/** XYZ (D65) -> Linear sRGB */
export declare function xyzToLinearRGB(xyz: XYZ_D65): sRGB;
export {};
/** XYZ (D65) -> Luv */
